@@ -19,17 +19,17 @@ sub message {
 sub serialize {
 	my (undef, $input, $is_key) = @_;
 	return join( '', 
-		ref($input) eq 'HASH' ? 
-			( '{ ', ( map { 
-				( t_LKT_Util->serialize( $_, 1 ), t_LKT_Util->serialize( $input->{$_} ) ) 
-			} sort keys %{$input} ), '}, ' ) 
+		!defined($input) ?
+			'undef'.($is_key ? ' => ' : ', ')
 		: ref($input) eq 'ARRAY' ? 
 			( '[ ', ( map { 
 				( t_LKT_Util->serialize( $_ ) ) 
 			} @{$input} ), '], ' ) 
-		: defined($input) ?
-			'\''.$input.'\''.($is_key ? ' => ' : ', ')
-		: 'undef'.($is_key ? ' => ' : ', ')
+		: ref($input) eq 'HASH' ? 
+			( '{ ', ( map { 
+				( t_LKT_Util->serialize( $_, 1 ), t_LKT_Util->serialize( $input->{$_} ) ) 
+			} sort keys %{$input} ), '}, ' ) 
+		: '\''.$input.'\''.($is_key ? ' => ' : ', ')
 	);
 }
 
